@@ -9,18 +9,22 @@
 #' \code{threads_related_to_channel}: channel ID.
 #'  
 #' @param part  Comment resource requested. Required. Comma separated list of one or more of the 
-#' following: \code{id, snippet}. e.g., "id, snippet", "id" Default: \code{snippet}.  
-#' @param simplify Data Type: Boolean. Default is TRUE. If TRUE, the function returns a data frame. Else a list with all the information returned.
+#' following: \code{id, snippet}. e.g., \code{"id, snippet"}, \code{"id"}, etc. Default: \code{snippet}.  
 #' @param max_results  Maximum number of items that should be returned. Integer. Optional. Can be between 20 and 100. Default is 100.
 #' @param page_token  Specific page in the result set that should be returned. Optional.
-#' @param text_format Data Type: Character. Default is "html". Only takes "html" or "plainText." Optional. 
+#' @param text_format Data Type: Character. Default is \code{"html"}. Only takes \code{"html"} or \code{"plainText"}. Optional. 
+#' @param simplify Data Type: Boolean. Default is \code{TRUE}. If \code{TRUE}, the function returns a data frame. Else a list with all the information returned.
 #' @param \dots Additional arguments passed to \code{\link{tuber_GET}}.
 #'  
 #' @return 
 #' Nested named list. The entry \code{items} is a list of comments along with meta information. 
 #' Within each of the \code{items} is an item \code{snippet} which has an item \code{topLevelComment$snippet$textDisplay}
 #' that contains the actual comment.
-#'  
+#' 
+#' If simplify is \code{TRUE}, a \code{data.frame} with the following columns:
+#' \code{authorDisplayName, authorProfileImageUrl, authorChannelUrl, authorChannelId.value, videoId, textDisplay,          
+#' canRate, viewerRating, likeCount, publishedAt, updatedAt}
+#' 
 #' @export
 #' @references \url{https://developers.google.com/youtube/v3/docs/commentThreads/list}
 #' 
@@ -34,7 +38,7 @@
 
 get_comment_threads <- function (filter=NULL, part="snippet", text_format="html", simplify=TRUE, max_results=100, page_token = NULL, ...) {
 
-	if (max_results < 20 | max_results > 100) stop("max_results only takes a value between 20 and 100")
+	if (max_results < 20 | max_results > 100) stop("max_results only takes a value between 20 and 100.")
 	if (text_format != "html" & text_format !="plainText") stop("Provide a legitimate value of textFormat.")
 
 	if (!(names(filter) %in% c("video_id", "channel_id", "thread_id", "threads_related_to_channel"))) stop("filter can only take one of values: channel_id, video_id, parent_id, threads_related_to_channel.")
@@ -51,8 +55,7 @@ get_comment_threads <- function (filter=NULL, part="snippet", text_format="html"
 	
 	if (simplify==TRUE & part=="snippet") {
 		simple_res  <- lapply(res$items, function(x) unlist(x$snippet$topLevelComment$snippet))
-		simpler_res <- as.data.frame(do.call(rbind, simple_res))
-
+		simpler_res <- ldply(simple_res, rbind)
 		return(simpler_res)
 	}
 
