@@ -2,6 +2,8 @@
 #'
 #' @name tuber
 #' @importFrom httr GET POST authenticate config stop_for_status upload_file content oauth_endpoints oauth_app oauth2.0_token
+#' @importFrom utils read.table
+#' @importFrom plyr ldply
 #' @docType package
 NULL
 
@@ -11,7 +13,7 @@ NULL
 yt_check_token <- function() {
 
 	app_token = getOption('google_token')
-    if (is.null(app_token)) stop("Please get a token using yt_oauth()")
+    if (is.null(app_token)) stop("Please get a token using yt_oauth().\n")
 
 }
 
@@ -33,7 +35,7 @@ function(path, query, ...) {
 
 	req <- GET("https://www.googleapis.com", path=paste0("youtube/v3/", path), query=query, config(token = getOption("google_token")), ...)
 	
-	stop_for_status(req)
+	tuber_check(req)
 	res <- content(req)
 
 	res
@@ -55,8 +57,22 @@ function(path, query, body="", ...) {
 	yt_check_token()
 	
 	req <- POST("https://www.googleapis.com", path=paste0("youtube/v3/", path), body=body, query=query, config(token = getOption("google_token")), ...)
-	stop_for_status(req)
+	tuber_check(req)
 	res <- content(req)
 
 	res
-}
\ No newline at end of file
+}
+
+#'
+#' Request Response Verification
+#' 
+#' @param  req request
+#' @return in case of failure, a message
+
+tuber_check <- 
+function(req) {
+
+  if (req$status_code < 400) return(invisible())
+
+  stop("HTTP failure: ", req$status_code, "\n", call. = FALSE)
+} 
